from setuptools import setup, find_packages

setup(
    name="ErfanIO",
    version="0.0.2",
    packages=find_packages(),
    url="https://gitlab.com/Azadeh-Afzar/Utility-Development/ErfanIO",
    license="AGPL-3.0",
    author="Mohammad Mahdi Baghbani Pourvahid",
    author_email="MahdiBaghbani@protonmail.com",
    description="Encryption library",
)
